==> oranchelo-icon-theme-0.7.4-noarch-1_slonly.txz: usr/doc/oranchelo-icon-theme-0.7.4/README.md <==
Oranchelo Icon Theme
===============
<p align="center"><img title="Oranchelo Icon Theme" src="http://oi64.tinypic.com/30s9abb.jpg"/></p>

Oranchelo is a flat-design icon theme for XFCE4 based on [Super Flat Remix](https://github.com/daniruiz/Super-Flat-Remix) and inspired by "Corny icons" by Patryk Goworowski.

### Installation

##### Ubuntu and derivatives

You can use the Oranchelo [PPA](https://launchpad.net/~oranchelo/+archive/ubuntu/oranchelo-icon-theme):

    sudo add-apt-repository ppa:oranchelo/oranchelo-icon-theme
    sudo apt-get update
    sudo apt-get install oranchelo-icon-theme

or download equivalent .deb for [14.04 Trusty Tahr](https://github.com/OrancheloTeam/oranchelo-icon-theme/releases/download/v0.7.4/oranchelo-icon-theme_0.7.4.ubuntu14.04.1_all.deb) or [16.04 Xenial Xerus](https://github.com/OrancheloTeam/oranchelo-icon-theme/releases/download/v0.7.4/oranchelo-icon-theme_0.7.4.ubuntu16.04.1_all.deb).

##### Arch and derivatives

You can install Oranchelo from [AUR](https://aur.archlinux.org/packages/oranchelo-icon-theme-git):

    yaourt oranchelo-icon-theme-git

#####Fedora and RPM-based

You can download .rpm [here](https://github.com/OrancheloTeam/oranchelo-icon-theme/releases/download/v0.7.4/oranchelo-icon-theme-0.7.4-1.fc23.noarch.rpm).

#####From sources

Clone or download repository and install it traditionally:

    sudo make install

or using interactive installer:

    ./oranchelo-installer.sh

Do not forget set the execution permissions for script installer!

#####Manual installation

Alternatively, click the Download ZIP button on the right area of this site. Later move the directories Oranchelo and Oranchelo-Green to `/usr/share/icons` or `~.local/share/icons`

###Getting the Source

The source for Oranchelo Icon Theme can be found [here](http://zayronxio.deviantart.com/art/Oranchelo-icons-beta-v0-7-4-567346368).

Packages sources:

- [Oranchelo-icon-theme-pkgbuild-arch](https://github.com/fjospinas/oranchelo-incon-theme-pkgbuild-arch)
- [Oranchelo-icon-theme-spec-for-fedora](https://github.com/fjospinas/Oranchelo-icon-theme-spec-for-fedora)

###Contributing

For any suggestion or request icons exists a [group in Facebook](https://www.facebook.com/groups/887649787956083/).

###Inspired projects

#####Simplex Icons

[Fork](http://dannexreloadex.deviantart.com/art/Simplex-icons-v0-2-beta-597696153) from Simple Icons by Camilo Higuita and inspired by Oranchelo Icon Theme by Zayronxio.

==> oranchelo-icon-theme-0.8.0.1-noarch-1_slonly.txz: usr/doc/oranchelo-icon-theme-0.8.0.1/README.md <==
Oranchelo Icon Theme
===============
<p align="center"><img title="Oranchelo Icon Theme" src="http://oi66.tinypic.com/293ee01.jpg"/></p>

Oranchelo is a flat-design icon theme for XFCE4 based on [Super Flat Remix](https://github.com/daniruiz/Super-Flat-Remix) and inspired by "Corny icons" by Patryk Goworowski.

### Installation

##### Ubuntu and derivatives

You can use the Oranchelo [PPA](https://launchpad.net/~oranchelo/+archive/ubuntu/oranchelo-icon-theme):

    sudo add-apt-repository ppa:oranchelo/oranchelo-icon-theme
    sudo apt-get update
    sudo apt-get install oranchelo-icon-theme

or download equivalent .deb for [14.04 Trusty Tahr](https://github.com/OrancheloTeam/oranchelo-icon-theme/releases/download/v0.7.4.4/oranchelo-icon-theme_0.7.4.4.ubuntu14.04.1_all.deb) or [16.04 Xenial Xerus](https://github.com/OrancheloTeam/oranchelo-icon-theme/releases/download/v0.7.4.4/oranchelo-icon-theme_0.7.4.4.ubuntu16.04.1_all.deb).

##### Arch and derivatives

You can install Oranchelo from [AUR](https://aur.archlinux.org/packages/oranchelo-icon-theme-git):

    yaourt oranchelo-icon-theme-git

##### Fedora and RPM-based

You can download .rpm for [Fedora 24](https://github.com/OrancheloTeam/oranchelo-icon-theme/releases/download/v0.7.4.4/oranchelo-icon-theme-0.7.4.4-1.fc26.noarch.rpm) or [Fedora 25](https://github.com/OrancheloTeam/oranchelo-icon-theme/releases/download/v0.7.4.4/oranchelo-icon-theme-0.7.4.4-1.fc27.noarch.rpm).

##### From sources

Clone or download repository and install it traditionally:

    sudo make install

or using interactive installer:

    ./oranchelo-installer.sh

Do not forget set the execution permissions for script installer!

##### Manual installation

Alternatively, click the Download ZIP button on the right area of this site. Later move the directories Oranchelo and Oranchelo-Green to `/usr/share/icons` or `~.local/share/icons`

### Getting the Source

The source for Oranchelo Icon Theme can be found [here](https://www.opendesktop.org/p/1015801/).

Packages sources:

- [Oranchelo-icon-theme-pkgbuild-arch](https://github.com/fjospinas/oranchelo-incon-theme-pkgbuild-arch)
- [Oranchelo-icon-theme-spec-for-fedora](https://github.com/fjospinas/Oranchelo-icon-theme-spec-for-fedora)

### Contributing

For any suggestion or request icons exists a [group in Facebook](https://www.facebook.com/groups/887649787956083/).

### Inspired projects

##### Simplex Icons

[Fork](http://dannexreloadex.deviantart.com/art/Simplex-icons-v0-2-beta-597696153) from Simple Icons by Camilo Higuita and inspired by Oranchelo Icon Theme by Zayronxio.
